Learn R Programming

MantaID (version 1.0.4)

mi_get_miss: Observe the distribution of the false response of the test set.

Description

Observe the distribution of the false response of the test set.

Usage

mi_get_miss(predict)

Value

A tibble data frame that records the number of wrong predictions for each category ID

Arguments

predict

An R6 class PredictionClassif.