Learn R Programming

MantaID (version 1.0.4)

mi_run_bmr: Compare classification models with small samples.

Description

Compare classification models with small samples.

Usage

mi_run_bmr(data, row_num = 1000, resamplings = rsmps("cv", folds = 10))

Value

A list of R6 class of benchmark results and scores of test set. examples data(mi_data_procID) mi_run_bmr(mi_data_procID)

Arguments

data

A tibble.All are numeric except the first column is a factor.

row_num

The number of samples used.

resamplings

R6/Resampling.Resampling method.