powered by
Observe the distribution of the false response of the test set.
mi_get_miss(predict)
A tibble data frame that records the number of wrong predictions for each category ID
An R6 class PredictionClassif.
PredictionClassif