Compare classification models with small samples.
mi_run_bmr(data, row_num = 1000, resamplings = rsmps("cv", folds = 10))A list of R6 class of benchmark results and scores of test set. examples data(mi_data_procID) mi_run_bmr(mi_data_procID)
A tibble.All are numeric except the first column is a factor.
The number of samples used.
R6/Resampling.Resampling method.